@@ -64,7 +64,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2020 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -230,7 +230,6 @@ int MdcPrintValue(FILE *fp, Uint8 *pvalue, Uint16 type)
       fprintf(fp,"%d",val[0]);
     }
     break;
-#ifdef HAVE_8BYTE_INT
    case BIT64_S:
     {
       Int64 *val = (Int64 *) pvalue;
@@ -243,7 +242,6 @@ int MdcPrintValue(FILE *fp, Uint8 *pvalue, Uint16 type)
       fprintf(fp,"%lu",val[0]);
     }
     break;
-#endif
    case FLT32:
     {
       float *val = (float *) pvalue;
@@ -416,7 +414,7 @@ int MdcPutDefault(char string[]) /* 1=default  or 0=no default */
 
 int MdcGetRange(const char *item, Uint32 *from, Uint32 *to, Uint32 *step)
 {
-  Uint32 a1, a2, t;
+  Uint32 a1=0, a2=0, t=1;
 
   /* read range values */
   if (strchr(item,':') != 0 ) {
@@ -429,8 +427,8 @@ int MdcGetRange(const char *item, Uint32 *from, Uint32 *to, Uint32 *step)
     /* range v2 */
     sscanf(item,"%u-%u",&a1,&a2); t=1;
   }else{
-    /* single */
-    sscanf(item,"%u",&a1); a2=a1;   t=1;
+    /* single item */
+    sscanf(item,"%u",&a1); a2 = a1;
   }
 
   /* some sanity checks */
