@@ -19,7 +19,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2020 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -269,7 +269,7 @@ Format DICOM:\n\
   if (XMDC_GUI == MDC_NO) {
   MdcPrntScrn("\
 \n  -optgif, --options-gif        ask for GIF related options\
-\n"); 
+\n");
   }else{
   MdcPrntScrn("\
 \n <none>\
@@ -329,7 +329,7 @@ void MdcPrintShortInfo(void)
   }
     MdcPrntScrn(" Medical Image Conversion Utility\n");
     MdcPrntScrn("(X)MedCon %s\n",MdcGetLibShortVersion());
-    MdcPrntScrn("Copyright (C) 1997-2018 by Erik Nolf\n\n");
+    MdcPrntScrn("Copyright (C) 1997-2020 by Erik Nolf\n\n");
 
   if (XMDC_GUI == MDC_YES) {
     MdcPrntScrn("Try \'xmedcon --help\' for more information.\n\n");
@@ -344,7 +344,7 @@ void MdcPrintShortInfo(void)
 void MdcPrintUsage(char *pgrname)
 {
 
-  /* allow usage info to stdout */ 
+  /* allow usage info to stdout */
   /* |more only catches stdout  */
   MDC_FILE_STDOUT = MDC_NO;
 
@@ -367,7 +367,7 @@ void MdcPrintUsage(char *pgrname)
   MdcPrntScrn("  -p, --print-values       print values of specified pixels\n");
   MdcPrntScrn("  -pa, --print-all-values  print all values without asking\n");
   MdcPrntScrn("  -r, --rename-file        rename file after user input\n");
-  MdcPrntScrn("  -w, --overwrite-files    always overwrite files\n"); 
+  MdcPrntScrn("  -w, --overwrite-files    always overwrite files\n");
   MdcPrintGlobalOptions();
   MdcPrintLocalOptions();
 
@@ -401,14 +401,14 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
 
   /* limit number of files */
   if (MAXFILES > MDC_MAX_FILES || MAXFILES <= 0) MAXFILES = MDC_MAX_FILES;
- 
+
   fi->map = MDC_MAP_GRAY;      /* default color map */
- 
+
   if ( argc == 1 ) return(MDC_BAD_CODE);
 
 
   /* initialize some stuff */
-  files[0]=NULL;  
+  files[0]=NULL;
   memset(convs,0,sizeof(int)*MDC_MAX_FRMTS);
   memset(total,0,sizeof(int)*2);
   mdcbufr[0]='\0';
@@ -440,7 +440,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
      }else if ( (strcasecmp(argv[a],"-db") == 0) ||
                 (strcasecmp(argv[a],"--database") == 0) ) {
        if (XMDC_GUI == MDC_NO) {
-         MDC_INFO_DB = MDC_YES; MDC_INFO = MDC_NO; 
+         MDC_INFO_DB = MDC_YES; MDC_INFO = MDC_NO;
        }
        continue;
      }else if ( (strcasecmp(argv[a],"-alias") == 0) ||
@@ -505,7 +505,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
      }else if ( (strcasecmp(argv[a],"-ident") == 0) ||
                 (strcasecmp(argv[a],"--identify") == 0) ) {
        if (XMDC_GUI == MDC_NO) {
-         MDC_PATIENT_IDENT = MDC_YES; 
+         MDC_PATIENT_IDENT = MDC_YES;
        }
        continue;
      }else if ( (strcasecmp(argv[a],"-o") == 0) ||
@@ -517,7 +517,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
                 (strcasecmp(argv[a],"--print-values") == 0) ) {
        if (XMDC_GUI == MDC_NO) {
          MDC_PIXELS=MDC_YES;   MDC_INFO=MDC_NO;
-         MDC_NEGATIVE=MDC_YES; MDC_CALIBRATE=MDC_YES; 
+         MDC_NEGATIVE=MDC_YES; MDC_CALIBRATE=MDC_YES;
        }
        continue;
      }else if ( (strcasecmp(argv[a],"-pa") == 0) ||
@@ -531,7 +531,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
      }else if ( (strcasecmp(argv[a],"-r") == 0) ||
                 (strcasecmp(argv[a],"--rename-file") == 0) ) {
        if (XMDC_GUI == MDC_NO) {
-         MDC_RENAME = MDC_YES; 
+         MDC_RENAME = MDC_YES;
        }
        continue;
      }else if ( (strcasecmp(argv[a],"-w") == 0) ||
@@ -637,7 +637,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
        sscanf(argv[a],"-si=%f:%f",&mdc_si_slope,&mdc_si_intercept);
        continue;
      }else if ( strstr(argv[a],"-cw=") != NULL ) {
-       MDC_FORCE_CONTRAST = MDC_YES; MDC_CONTRAST_REMAP = MDC_YES; 
+       MDC_FORCE_CONTRAST = MDC_YES; MDC_CONTRAST_REMAP = MDC_YES;
        sscanf(argv[a],"-cw=%f:%f",&mdc_cw_centre,&mdc_cw_width);
        continue;
      }else if ( (strcasecmp(argv[a],"-mosaic") == 0) ||
@@ -777,7 +777,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
                 (strcasecmp(argv[a],"--silent") == 0) ) {
        MDC_BLOCK_MESSAGES = MDC_LEVEL_ALL; continue;
      }
-     
+
      if ( ARG == -1 ) return(MDC_BAD_CODE);              /* no '-c' or '-f' */
 
      switch (ARG) {
@@ -797,7 +797,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
 #if MDC_INCLUDE_GIF
          if ( strcasecmp(argv[a],"gif")  == 0 ) {
              convs[MDC_FRMT_GIF]+=1; total[MDC_CONVS]+=1;
-         }else 
+         }else
 #endif
 #if MDC_INCLUDE_INW
          if ( strcasecmp(argv[a],"inw")  == 0 ) {
@@ -848,9 +848,9 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
          if ( strcasecmp(argv[a],"-") == 0) {
            MDC_FILE_STDOUT = MDC_YES;
          }else
-         
+
          MdcPrntErr(MDC_BAD_CODE,"Unsupported conversion \"%s\"",argv[a]);
- 
+
          break;
 
        case MDC_ARG_FILE:
@@ -858,12 +858,12 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
          if (MDC_FILE_STDIN == MDC_NO) {
            /* input from files */
 
-           if ( total[MDC_FILES] == MAXFILES)
+           if ( total[MDC_FILES] == MAXFILES ) {
              MdcPrntErr(MDC_OVER_FLOW,"Too many files specified (max=%d)"
                                      ,MAXFILES);
-           else
+           }else{
              files[total[MDC_FILES]]=argv[a]; total[MDC_FILES]+=1;
-
+           }
          }else{
            /* input from stdin */
 
@@ -930,17 +930,17 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
              DO_STDIN = MDC_YES; MDC_FRMT_INPUT = MDC_FRMT_NIFTI;
            }else
 #endif
-           
+
              { DO_STDIN = MDC_NO;  MDC_FRMT_INPUT = MDC_FRMT_NONE; }
 
-         } 
+         }
 
          if (strcmp(argv[a],"-") == 0) DO_STDIN = MDC_YES;
 
 
          if (DO_STDIN == MDC_YES) {
              files[0]=argv[a]; total[MDC_FILES] = 1;
-             DO_STDIN = MDC_NO; MDC_FILE_STDIN = MDC_YES; 
+             DO_STDIN = MDC_NO; MDC_FILE_STDIN = MDC_YES;
          }
 
          break;
@@ -986,7 +986,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
   /* print database info; legacy option, just used within ECAT */
   if (MDC_INFO_DB == MDC_YES) {
     if (total[MDC_FILES] > 1)
-      MdcPrntErr(MDC_NO_CODE,"Option '-db' only usefull one file at a time");
+      MdcPrntErr(MDC_NO_CODE,"Option '-db' only useful one file at a time");
     if (MDC_CONVERT == MDC_YES)
       MdcPrntErr(MDC_NO_CODE,"Option '-db' useless with '-c' conversion");
   }
@@ -994,7 +994,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
   /* echo alias name; single option allowed */
   if (MDC_ECHO_ALIAS == MDC_YES) {
     if (total[MDC_FILES] > 1)
-      MdcPrntErr(MDC_NO_CODE,"Option '-ean' only usefull one file at a time");
+      MdcPrntErr(MDC_NO_CODE,"Option '-ean' only useful one file at a time");
     if (MDC_CONVERT == MDC_YES)
       MdcPrntErr(MDC_NO_CODE,"Option '-ean' useless with '-c' conversion");
   }
@@ -1018,7 +1018,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
     if (MDC_VERBOSE == MDC_YES)
       MdcPrntErr(MDC_NO_CODE,"Option '-v' disallowed with stdout file writing");
 
-    if ((total[MDC_FILES] > 1) && (MDC_FILE_STACK == MDC_NO)) 
+    if ((total[MDC_FILES] > 1) && (MDC_FILE_STACK == MDC_NO))
       MdcPrntErr(MDC_NO_CODE,"Only one file supported when writing to stdout");
 
     if (total[MDC_CONVS] > 1)
@@ -1042,16 +1042,16 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
   }
 
   /* quantification troubles */
-  if (MDC_INFO == MDC_YES) { 
+  if (MDC_INFO == MDC_YES) {
     if (MDC_QUANTIFY == MDC_YES) {
       MDC_NEGATIVE=MDC_YES; MDC_CALIBRATE=MDC_NO;
     }else{
-      MDC_NEGATIVE=MDC_YES; MDC_CALIBRATE=MDC_YES; 
+      MDC_NEGATIVE=MDC_YES; MDC_CALIBRATE=MDC_YES;
     }
   }
 
-  if ((MDC_ANLZ_SPM == MDC_YES) && (MDC_QUANTIFY == MDC_NO) 
-                                && (MDC_CALIBRATE == MDC_NO) ) 
+  if ((MDC_ANLZ_SPM == MDC_YES) && (MDC_QUANTIFY == MDC_NO)
+                                && (MDC_CALIBRATE == MDC_NO) )
     MdcPrntWarn("For SPM scaling you should select a quantification option");
 
   if (MDC_INTERACTIVE == MDC_YES) {
@@ -1068,7 +1068,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
   if ((MDC_CONVERT  == MDC_YES) || (XMDC_GUI == MDC_YES)) {
     /* with output file */
     if (XMDC_GUI == MDC_NO) {
-      if ( total[MDC_CONVS] == 0 ) 
+      if ( total[MDC_CONVS] == 0 )
         MdcPrntErr(MDC_NO_CODE,"No conversion formats specified");
       if (MDC_PIXELS   == MDC_YES)
         MdcPrntErr(MDC_NO_CODE,"Options '-c' & '-p(a)' are mutually exclusive");
@@ -1085,13 +1085,13 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
   if ( (MDC_PATIENT_ANON == MDC_YES) && (MDC_PATIENT_IDENT == MDC_YES) )
     MdcPrntErr(MDC_NO_CODE,"Options '-anon' & '-ident' are mutually exclusive");
 
-  /* the must do FINAL quantification/calibration check */ 
+  /* the must do FINAL quantification/calibration check */
   if ( (MDC_QUANTIFY == MDC_YES) && (MDC_CALIBRATE == MDC_YES) )
     MdcPrntErr(MDC_NO_CODE,"Options '-qs' & '-qc' are mutually exclusive");
 
   /* some checks on mosaic settings */
-  if ( (MDC_DICOM_MOSAIC_DO_INTERL == MDC_YES) && 
-       (MDC_DICOM_MOSAIC_FORCED == MDC_NO) ) 
+  if ( (MDC_DICOM_MOSAIC_DO_INTERL == MDC_YES) &&
+       (MDC_DICOM_MOSAIC_FORCED == MDC_NO) )
     MdcPrntWarn("Option '-interl' requires mosaic forced");
 
   /* color */
@@ -1129,7 +1129,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
     MdcPrntMesg("Input  from stdin  is ON");
     if (MDC_FILE_STDOUT == MDC_YES)
     MdcPrntMesg("Output to  stdout  is ON");
-    if (MDC_QUANTIFY == MDC_YES) 
+    if (MDC_QUANTIFY == MDC_YES)
     MdcPrntMesg("Quantification     is ON  (ECAT units=[counts/second/pixel])");
     if (MDC_CALIBRATE == MDC_YES)
     MdcPrntMesg("Calibration        is ON  (ECAT units=[uCi/ml])");
@@ -1145,7 +1145,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
     MdcPrntMesg("Mosaic forced      is ON");
     if (MDC_DICOM_MOSAIC_FIX_VOXEL == MDC_YES)
     MdcPrntMesg("Mosaic fix voxel   is ON");
-    if (MDC_TRUE_GAP == MDC_YES) 
+    if (MDC_TRUE_GAP == MDC_YES)
     MdcPrntMesg("True gap/overlap   is ON");
     if (MDC_DICOM_WRITE_IMPLICIT == MDC_YES)
     MdcPrntMesg("Dicom implicit     is ON");
@@ -1188,22 +1188,22 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
     if (MDC_MAKE_GRAY == MDC_YES)
     MdcPrntMesg("Color to gray      is ON");
 
-     
+
     if (MDC_FORCE_INT != MDC_NO) {
       switch (MDC_FORCE_INT) {
-        case BIT8_U : 
+        case BIT8_U :
             MdcPrntMesg("Writing Uint8 pixs is ON  (quantified values lost!)");
             break;
-        case BIT16_S: 
+        case BIT16_S:
             MdcPrntMesg("Writing Int16 pixs is ON  (quantified values lost!)");
             break;
-        default     : 
+        default     :
             MdcPrntMesg("Writing Int16 pixs is ON  (quantified values lost!)");
       }
 
-      if (MDC_INT16_BITS_USED == 12) 
+      if (MDC_INT16_BITS_USED == 12)
             MdcPrntMesg("Using only 12 bits is ON");
-      
+
     }
   }
 
@@ -1226,7 +1226,7 @@ char *MdcApplyReadOptions(FILEINFO *fi)
     if ((msg = MdcEditFI(fi)) != NULL) return(msg);
   }
 
-  /* print FILEINFO structure */  
+  /* print FILEINFO structure */
   if (MDC_DEBUG)  MdcPrintFI(fi);
 
   /* print out pixel requested values */
