@@ -20,7 +20,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2020 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -151,7 +151,7 @@ typedef struct mdc_mat_main_header7 {
   Int16 system_type;
   Int16 file_type;
   char serial_number[10];
-  Uint32 scan_start_time;
+  Int32 scan_start_time;
   char isotope_name[8];
   float isotope_halflife;
   char radiopharmaceutical[32];
@@ -178,7 +178,7 @@ typedef struct mdc_mat_main_header7 {
   float patient_age;
   float patient_height;
   float patient_weight;
-  Uint32 patient_birth_date;
+  Int32 patient_birth_date;
   char physician_name[32];
   char operator_name[32];
   char study_description[32];
