@@ -16,7 +16,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2020 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -405,9 +405,10 @@ const char *MdcWriteNIFTI(FILEINFO *fi)
   bname = nifti_makebasename(fi->opath);
   if (bname == NULL) return("NIFTI Base filename allocation failed");
 
-  /* get rid of any extension left, like .img.hdr -> .img remains */
-  /* which would result in a misappropriate two file nifti output */
-  pext = strchr(bname,'.'); if (pext != NULL) pext[0]='\0';
+  /* we explicitely must get rid of any .img extension in the filename     */
+  /* otherwise nifti1 library writes an unwanted two file .hdr & .img pair */
+  /* by simply ignoring nifti_type; see nifti1_io.c at nifti_makehdrname() */
+  pext = strstr(bname,".img"); if (pext != NULL) pext[0]='\0';
 
   if (MDC_FILE_OVERWRITE == MDC_YES) {
     ret = nifti_set_filenames(nim,bname,0,1);
