@@ -30,7 +30,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2020 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -172,8 +172,8 @@ void XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format)
     formatmenu = gtk_option_menu_new();
     menu = gtk_menu_new();
 
-    memset(format_to_use,MDC_FRMT_NONE,MDC_MAX_FRMTS);
-    memset(mitem_nr,-1,MDC_MAX_FRMTS);
+    memset(format_to_use,0,sizeof(format_to_use));
+    memset(mitem_nr,0,sizeof(mitem_nr));
 
 /* format Raw Binary */
     if (LOOK && (format == MDC_FRMT_RAW)) {
@@ -181,7 +181,6 @@ void XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format)
     }
     format_to_use[MDC_FRMT_RAW]=MDC_FRMT_RAW;
     mitem_nr[MDC_FRMT_RAW] = item++;
-
     menuitem = gtk_menu_item_new_with_label(FrmtString[MDC_FRMT_RAW]);
 
     gtk_signal_connect( GTK_OBJECT(menuitem), "activate",
