@@ -14,7 +14,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2020 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -85,7 +85,7 @@ int main(int argc, char *argv[])
     sResizeSelection.CurType = XMDC_RESIZE_ORIGINAL;
     sPagesSelection.CurType = XMDC_PAGES_FRAME_BY_FRAME;
     sRenderSelection.Dither = GDK_RGB_DITHER_MAX;
-    sRenderSelection.Interp = GDK_INTERP_HYPER; /*GDK_INTERP_BILINEAR;*/
+    sRenderSelection.Interp = GDK_INTERP_BILINEAR; /* GDK_INTERP_HYPER; */
     sGbc.mod.gamma = 256;
     sGbc.mod.brightness = 256;
     sGbc.mod.contrast = 256;
