@@ -21,7 +21,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2020 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -241,7 +241,7 @@ void XMdcPagesSel(void)
 
     button = gtk_radio_button_new_with_label(NULL, "frame by frame (volume)");
     gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
-    if (sPagesSelection.CurType == XMDC_PAGES_FRAME_BY_FRAME);
+    if (sPagesSelection.CurType == XMDC_PAGES_FRAME_BY_FRAME)
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
     gtk_widget_show(button);
     sPagesSelection.FrameByFrame = button;
