@@ -17,7 +17,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2020 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -144,10 +144,6 @@ void XMdcImagesZoomIn(GtkWidget *window)
   ZoomStruct *zoom;
   int w, h, z;
 
-#ifdef _WIN32
-  gtk_widget_hide(window);
-#endif
-
   zoom = (ZoomStruct *)gtk_object_get_data(GTK_OBJECT(window),"zoomstruct");
 
   z = XMdcGetZoomFactor(zoom,XMDC_ZOOM_IN);
@@ -178,10 +174,6 @@ void XMdcImagesZoomIn(GtkWidget *window)
 
   gtk_window_set_policy(GTK_WINDOW(window),FALSE,FALSE,FALSE);
 
-#ifdef _WIN32
-  gtk_widget_show(window);
-#endif
-
 }
 
 void XMdcImagesZoomOut(GtkWidget *window)
@@ -190,10 +182,6 @@ void XMdcImagesZoomOut(GtkWidget *window)
   ZoomStruct *zoom;
   int w, h, z;
 
-#ifdef _WIN32
-  gtk_widget_hide(window);
-#endif
-
   zoom = (ZoomStruct *)gtk_object_get_data(GTK_OBJECT(window),"zoomstruct");
 
   z = XMdcGetZoomFactor(zoom,XMDC_ZOOM_OUT);
@@ -224,10 +212,6 @@ void XMdcImagesZoomOut(GtkWidget *window)
 
   gtk_window_set_policy(GTK_WINDOW(window),FALSE,FALSE,FALSE);
 
-#ifdef _WIN32
-  gtk_widget_show(window);
-#endif
-
 }
 
 gboolean XMdcImagesZoomCallbackClicked(GtkWidget *widget, GdkEventButton *button, GtkWidget *window)
